==> dart_code_metrics-4.2.0-dev.1.tar.gz: lib/src/analyzers/lint_analyzer/rules/rules_list/prefer_trailing_comma/prefer_trailing_comma.dart <==
import 'package:analyzer/dart/ast/ast.dart';
import 'package:analyzer/dart/ast/syntactic_entity.dart';
import 'package:analyzer/dart/ast/token.dart';
import 'package:analyzer/dart/ast/visitor.dart';
import 'package:analyzer/source/line_info.dart';

import '../../../../../utils/node_utils.dart';
import '../../../models/internal_resolved_unit_result.dart';
import '../../../models/issue.dart';
import '../../../models/replacement.dart';
import '../../../models/severity.dart';
import '../../models/flutter_rule.dart';
import '../../models/rule_documentation.dart';
import '../../rule_utils.dart';

part 'config_parser.dart';
part 'visitor.dart';

class PreferTrailingCommaRule extends FlutterRule {
  static const String ruleId = 'prefer-trailing-comma';

  static const _warningMessage = 'Prefer trailing comma.';
  static const _correctionMessage = 'Add trailing comma.';

  final int? _itemsBreakpoint;

  PreferTrailingCommaRule([Map<String, Object> config = const {}])
      : _itemsBreakpoint = _ConfigParser.parseBreakpoint(config),
        super(
          id: ruleId,
          documentation: const RuleDocumentation(
            name: 'Prefer trailing comma',
            brief:
                'Check for trailing comma for arguments, parameters, enum values and collections.',
          ),
          severity: readSeverity(config, Severity.warning),
          excludes: readExcludes(config),
        );

  @override
  Iterable<Issue> check(InternalResolvedUnitResult source) {
    final visitor = _Visitor(source.lineInfo, _itemsBreakpoint);

    source.unit.visitChildren(visitor);

    return visitor.nodes
        .map(
          (node) => createIssue(
            rule: this,
            location: nodeLocation(
              node: node,
              source: source,
              withCommentOrMetadata: true,
            ),
            message: _warningMessage,
            replacement: Replacement(
              comment: _correctionMessage,
              replacement:
                  '${source.content.substring(node.offset, node.end)},',
            ),
          ),
        )
        .toList(growable: false);
  }
}

==> dart_code_metrics-4.2.1.tar.gz: lib/src/analyzers/lint_analyzer/rules/rules_list/prefer_trailing_comma/prefer_trailing_comma.dart <==
import 'package:analyzer/dart/ast/ast.dart';
import 'package:analyzer/dart/ast/syntactic_entity.dart';
import 'package:analyzer/dart/ast/token.dart';
import 'package:analyzer/dart/ast/visitor.dart';
import 'package:analyzer/source/line_info.dart';

import '../../../../../utils/node_utils.dart';
import '../../../models/internal_resolved_unit_result.dart';
import '../../../models/issue.dart';
import '../../../models/replacement.dart';
import '../../../models/severity.dart';
import '../../models/common_rule.dart';
import '../../models/rule_documentation.dart';
import '../../rule_utils.dart';

part 'config_parser.dart';
part 'visitor.dart';

class PreferTrailingCommaRule extends CommonRule {
  static const String ruleId = 'prefer-trailing-comma';

  static const _warningMessage = 'Prefer trailing comma.';
  static const _correctionMessage = 'Add trailing comma.';

  final int? _itemsBreakpoint;

  PreferTrailingCommaRule([Map<String, Object> config = const {}])
      : _itemsBreakpoint = _ConfigParser.parseBreakpoint(config),
        super(
          id: ruleId,
          documentation: const RuleDocumentation(
            name: 'Prefer trailing comma',
            brief:
                'Check for trailing comma for arguments, parameters, enum values and collections.',
          ),
          severity: readSeverity(config, Severity.warning),
          excludes: readExcludes(config),
        );

  @override
  Iterable<Issue> check(InternalResolvedUnitResult source) {
    final visitor = _Visitor(source.lineInfo, _itemsBreakpoint);

    source.unit.visitChildren(visitor);

    return visitor.nodes
        .map(
          (node) => createIssue(
            rule: this,
            location: nodeLocation(
              node: node,
              source: source,
              withCommentOrMetadata: true,
            ),
            message: _warningMessage,
            replacement: Replacement(
              comment: _correctionMessage,
              replacement:
                  '${source.content.substring(node.offset, node.end)},',
            ),
          ),
        )
        .toList(growable: false);
  }
}
